@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 
-from mypy.nodes import CallExpr, NameExpr, StrExpr
+from mypy.nodes import CallExpr, RefExpr, StrExpr
 
 from refurb.error import Error
 
@@ -26,14 +26,17 @@ class ErrorInfo(Error):
 
     name = "simplify-path-constructor"
     code = 153
-    msg: str = 'Replace `Path(".")` with `Path()`'
-    categories = ["pathlib", "readability"]
+    categories = ("pathlib", "readability")
 
 
 def check(node: CallExpr, errors: list[Error]) -> None:
     match node:
         case CallExpr(
-            args=[StrExpr(value=".")],
-            callee=NameExpr(fullname="pathlib.Path"),
+            args=[StrExpr(value="." | "" as value)],
+            callee=RefExpr(fullname="pathlib.Path"),
         ):
-            errors.append(ErrorInfo(node.line, node.column))
+            errors.append(
+                ErrorInfo.from_node(
+                    node, f'Replace `Path("{value}")` with `Path()`'
+                )
+            )
