@@ -1,8 +1,11 @@
+import pathlib
 from pathlib import Path
 
 # these should match
 
 _ = Path(".")
+_ = Path("")
+_ = pathlib.Path(".")
 
 
 # these should not
